class ESClient:
    def __int__(self):
        pass

    def add_records(self, items):
        return items

    def get_records(self):
        pass

    def add_users(self, users):
        return users

    def add_actions(self, actions):
        return actions

    def query(self, **kwargs):
        pass
