__title__ = "Yodu.ai Recommendation Engine"
__version__ = "0.0.1"
__author__ = "Shashank Agarwal"
__license__ = "Apache"
__copyright__ = "Copyright 2022-present The Geek Labs"

# Synonyms
TITLE = __title__
VERSION = __version__
AUTHOR = __author__
LICENSE = __license__
COPYRIGHT = __copyright__
import yodu.settings
